@@ -22,6 +22,7 @@ class Query:
         limit_count: Optional[int],
         offset: Optional[int],
         fields: Optional[List],
+        exclude_fields: Optional[List],
         order_bys: Optional[List],
     ) -> None:
         self.query_offset = offset
@@ -30,6 +31,7 @@ class Query:
         self.filter_clauses = filter_clauses[:]
         self.exclude_clauses = exclude_clauses[:]
         self.fields = fields[:] if fields else []
+        self.exclude_fields = exclude_fields[:] if exclude_fields else []
 
         self.model_cls = model_cls
         self.table = self.model_cls.Meta.table
@@ -52,14 +54,17 @@ class Query:
         pkname_alias = self.model_cls.get_column_alias(self.model_cls.Meta.pkname)
         return f"{self.table.name}.{pkname_alias}"
 
+    def alias(self, name: str) -> str:
+        return self.model_cls.get_column_alias(name)
+
     def apply_order_bys_for_primary_model(self) -> None:  # noqa: CCR001
         if self.order_columns:
             for clause in self.order_columns:
                 if "__" not in clause:
                     clause = (
-                        text(f"{clause[1:]} desc")
+                        text(f"{self.alias(clause[1:])} desc")
                         if clause.startswith("-")
-                        else text(clause)
+                        else text(self.alias(clause))
                     )
                     self.sorted_orders[clause] = clause
         else:
@@ -68,7 +73,7 @@ class Query:
 
     def build_select_expression(self) -> Tuple[sqlalchemy.sql.select, List[str]]:
         self_related_fields = self.model_cls.own_table_columns(
-            self.model_cls, self.fields
+            self.model_cls, self.fields, self.exclude_fields
         )
         self.columns = self.model_cls.Meta.alias_manager.prefixed_columns(
             "", self.table, self_related_fields
@@ -88,6 +93,7 @@ class Query:
                 select_from=self.select_from,
                 columns=self.columns,
                 fields=self.fields,
+                exclude_fields=self.exclude_fields,
                 order_columns=self.order_columns,
                 sorted_orders=self.sorted_orders,
             )
@@ -126,3 +132,4 @@ class Query:
         self.columns = []
         self.used_aliases = []
         self.fields = []
+        self.exclude_fields = []
